/** 表格公用组件 */
import React, { Component } from 'react';
import { Table } from 'antd';
import './index.less';
import * as $$ from '../../../utils/utility';
export default class TableView extends Component {
	constructor(props) {
		super(props);
		this.config = {};
		this.state = {
			tableData: [],
			totalElements: 0,
			pageSize: this.props.formData.size,
			page: 1,
			loading: false,
		};
	}

	UNSAFE_componentWillMount() {}

	componentDidMount() {
		let { page, size } = this.props.formData;
		this.loadData(page, size);
	}

	loadData = (page, size) => {
		let { formData, extraFromData, url, watermeter, service } = this.props;
		this.setState({
			loading: true,
		});
		$$.ax
			.request({
				url,
				service,
				type: 'get',
				data: {
					...formData,
					...extraFromData,
					page,
					size,
				},
			})
			.then((res) => {
				if (res.type) {
					res.data.content = (res.data.content || []).map(({ ...a }, idx) => ({
						...a,
						index: idx + 1 + size * (page - 1),
						key: idx,
					}));
				}
				this.setState({
					tableData: res.data ? res.data.content : [],
					loading: false,
					totalElements: res.data ? res.data.totalElements : 0,
				});
			});
	};

	pageChange = (page, size) => {
		this.props.setFormData({
			...this.props.formData,
			page,
		});
		this.loadData(page, size);
	};

	onShowSizeChange = (current, size) => {
		this.props.setFormData({
			...this.props.formData,
			page: 1,
			size,
		});
		this.loadData(1, size);
	};

	itemRender = (current, type, originalElement) => {
		if (type === 'prev') {
			return <span>上一页&nbsp;</span>;
		} else if (type === 'next') {
			return <span>&nbsp;下一页</span>;
		}
		return originalElement;
	};

	render() {
		const { columns, rowSelection, rowClassName, bordered = true } = this.props;
		const { page, size } = this.props.formData;
		return (
			<div className="table-view-main">
				<Table
					rowSelection={rowSelection || null}
					rowKey={(record) => record.id}
					rowClassName={rowClassName}
					bordered={bordered}
					size="middle"
					className="rowColor"
					dataSource={this.state.tableData}
					loading={{ spinning: this.state.loading }}
					columns={columns}
					pagination={{
						pageSize: Number(size),
						onChange: this.pageChange,
						total: this.state.totalElements,
						showSizeChanger: true,
						onShowSizeChange: this.onShowSizeChange,
						showTotal: (total, range) => `共${total}条记录 `,
						// itemRender: this.itemRender,
						showQuickJumper: true,
						defaultCurrent: 1,
						current: Number(page),
					}}
				/>
			</div>
		);
	}
}
